@@ -167,6 +167,8 @@ public:
 
   virtual void construct_specified_columns(); //Delay actual use of set_column_*() stuff until this method is called.
 
+  virtual bool refresh_from_database();
+
   virtual void set_show_column_titles(bool bVal = true);
 
   virtual Gtk::TreeModel::iterator get_row(const Gnome::Gda::Value& key);
@@ -294,9 +296,6 @@ protected:
   typedef DbTreeModel type_model_store;
   Glib::RefPtr<type_model_store> m_refListStore;
 
-  //Hidden internal columns:
-  Gtk::TreeModelColumn<Gnome::Gda::Value>* m_modelcolumn_key; 
-
   //Columns, not including the hidden internal columns:
   typedef std::vector<DbAddDelColumnInfo> type_ColumnTypes;
   type_ColumnTypes m_ColumnTypes;
